@@ -336,22 +336,37 @@ class Deposits:
         depo_helpers = []
 
         for rate in rates:
-            if rate.start_basis:
-                start_basis = rate.start_basis
+            if rate.tenor in ['O/N', 'T/N', 'S/N']:
+                if rate.tenor == 'O/N': 
+                    start_basis = qle.StartBasis.today
+                elif rate.tenor == 'T/N':
+                    start_basis = qle.StartBasis.tom
+                else:
+                    start_basis = qle.StartBasis.spot
+                helper = ql.DepositRateHelper(rate.rate/100, 
+                                            ql.Period(rate.tenor), 
+                                            start_basis, 
+                                            self.__qlcalendar, 
+                                            business_day, 
+                                            False, 
+                                            day_count)
+                            
+            elif rate.tenor in ['1W', '2W', '3W']:
+                helper = ql.DepositRateHelper(rate.rate/100, 
+                                            ql.Period(rate.tenor), 
+                                            setting.start_basis, 
+                                            self.__qlcalendar, 
+                                            business_day, 
+                                            False, 
+                                            day_count)
             else:
-                start_basis = setting.start_basis
-            
-            if rate.eom:
-                eom = rate.eom
-            else:
-                eom = setting.eom
-            helper = ql.DepositRateHelper(rate.rate/100, 
-                                        ql.Period(rate.tenor), 
-                                        start_basis, 
-                                        self.__qlcalendar, 
-                                        business_day, 
-                                        eom, 
-                                        day_count)
+                helper = ql.DepositRateHelper(rate.rate/100, 
+                                            ql.Period(rate.tenor), 
+                                            setting.start_basis, 
+                                            self.__qlcalendar, 
+                                            business_day, 
+                                            setting.eom, 
+                                            day_count)
             depo_helpers.append(helper)
         return depo_helpers
 
@@ -538,7 +553,8 @@ class IRS:
 
 
 class Curve:
-    def __init__(self, day_count: qle.DayCount, deposits: Deposits = None, 
+    def __init__(self, day_count: qle.DayCount, method: qle.PiecewiseMethods = qle.PiecewiseMethods.logcubicdiscount,
+                deposits: Deposits = None, 
                 parbond: ParBond = None, fra: FRAs = None, 
                 ois: OIS=None, irs: IRS=None, qlcalendar=None):
         self.__day_count = day_count
@@ -547,14 +563,55 @@ class Curve:
         self.__fra = fra
         self.__ois = ois
         self.__irs = irs
+        self.__method = method
         #self.__current_date = current_date
         #if qlcalendar:
         #    self.__qlcalendar = qlcalendar
         #else:
         #    self.__qlcalendar = ql.NullCalendar()  
 
+    @property
+    def deposit(self):
+        return self.__deposit
 
-    def piecewise(self, date: dt64 = None, method: qle.PiecewiseMethods = qle.PiecewiseMethods.logcubicdiscount):
+    @deposit.setter
+    def deposit(self, deposit):
+        self.__deposit = deposit  
+
+    @property
+    def parbond(self):
+        return self.__parbond
+
+    @parbond.setter
+    def parbond(self, parbond):
+        self.__parbond = parbond 
+
+    @property
+    def fra(self):
+        return self.__fra
+
+    @fra.setter
+    def fra(self, fra):
+        self.__fra = fra  
+
+    @property
+    def ois(self):
+        return self.__ois
+
+    @ois.setter
+    def ois(self, ois):
+        self.__ois = ois 
+
+    @property
+    def irs(self):
+        return self.__irs
+
+    @irs.setter
+    def irs(self, irs):
+        self.__irs = irs  
+
+
+    def piecewise(self, date: dt64 = None):
         if date:
             vdate = ql.Date(datestr(date), '%Y-%m-%d')
         else:
@@ -571,6 +628,7 @@ class Curve:
             helpers += self.__irs.helpers()
 
         day_count = qlc.ql_day_count[self.__day_count]
+        method = self.__method
 
         if method == qle.PiecewiseMethods.loglineardiscount:
             t_structure = ql.PiecewiseLogLinearDiscount(vdate,
