@@ -90,7 +90,7 @@ class BondSetting(BaseModel):
     business_day: BusinessDay = BusinessDay.no_adjustment
     terminate_business_day: Optional[BusinessDay] = None
     date_gen: DateGeneration = DateGeneration.backward
-    is_eom: bool = False
+    is_eom: bool = True
 
 
     @validator('day_count')
