@@ -614,4 +614,97 @@ def data_EONIA():
                                         ql.QuoteHandle(ql.SimpleQuote(datum['rate']/100)), index)
                         for datum in ois_swap]
     
-    return depo_helper, ois_helper, ois_fwd_helper, ois_swap_helper
\ No newline at end of file
+    return depo_helper, ois_helper, ois_fwd_helper, ois_swap_helper
+
+
+def depo_data():
+    depo_rates = [
+        {"tenor": "1M", "rate": 2.00},
+        {"tenor": "2M", "rate": 2.05}, 
+        {"tenor": "3M", "rate": 2.10},
+        {"tenor": "6M", "rate": 2.20}
+    ]
+
+    rates = []
+    for depo_rate in depo_rates:
+        rate = Rate(**depo_rate)
+        rates.append(rate)
+
+    depo_sett = {
+        "start_basis": StartBasis.today, 
+        "business_day": BusinessDay.mod_following,
+        "day_count": DayCount.act_act_act365,
+        "eom": False
+        }
+    setting = DepoSetting(**depo_sett)
+    return setting, rates
+
+
+def parbond_data():
+    par_rates = [
+        {"tenor": "1Y", "rate": 2.30},
+        {"tenor": "2Y", "rate": 2.40}, 
+        {"tenor": "3Y", "rate": 2.50},
+        {"tenor": "5Y", "rate": 2.70},
+        {"tenor": "7Y", "rate": 2.80},
+        {"tenor": "10Y", "rate": 2.90},
+        {"tenor": "20Y", "rate": 3.00},
+        {"tenor": "30Y", "rate": 3.10}
+    ]
+    rates = []
+    for par_rate in par_rates:
+        rate = Rate(**par_rate)
+        rates.append(rate)
+
+    par_sett = {
+        "frequency": "Semi-Annual",
+        "start_basis": 2,
+        "day_count": "Actual/Actual (ISMA)",
+        "business_day": "Modified Following",
+        "terminate_business_day": "Modified Following",
+        "date_gen": "Backward from maturity date",
+        "is_eom":  False
+    }
+    setting = BondSetting(**par_sett)
+    return setting, rates
+
+
+def fra_data():
+    fra_rates = [
+        {"depo":{"tenor": "3M", "rate": 2.00, "start_basis": qle.StartBasis.spot}, "start_tenor": "1M"},
+        {"depo":{"tenor": "3M", "rate": 2.05, "start_basis": qle.StartBasis.spot}, "start_tenor": "4M"},
+        {"depo":{"tenor": "3M", "rate": 2.10, "start_basis": qle.StartBasis.spot}, "start_tenor": "7M"},
+        {"depo":{"tenor": "3M", "rate": 2.20, "start_basis": qle.StartBasis.spot}, "start_tenor": "10M"},
+        ]
+    rates = []
+    for fra_rate in fra_rates:
+        rate = FRA(**fra_rate)
+        rates.append(rate)
+    
+    return rates
+
+
+def ois_data():
+    ois = [{'tenor':"1W", 'rate': 2.00}, 
+            {'tenor':"2W", 'rate': 2.05}, 
+            {'tenor':"3W", 'rate': 2.1}]
+
+    rates = []
+    for oi in ois:
+        rate = pymodels.Rate(**oi)
+        rates.append(rate)
+
+    return rates
+
+
+def irs_data():
+    irs = [{'tenor':"1W", 'rate': 2.00}, 
+            {'tenor':"2W", 'rate': 2.05}, 
+            {'tenor':"3W", 'rate': 2.1}]
+
+    rates = []
+    for ir in irs:
+        rate = pymodels.Rate(**ir)
+        rates.append(rate)
+
+    return rates
