@@ -192,14 +192,68 @@ def ql_spread_handle(value_date: str,
     return handle
     
 
-def qlFlatForward(flatforward: FlatForwardCurve):
-    qlDate = datestr_to_qldate(flatforward.date)
-    qlHandle = ql.QuoteHandle(ql.SimpleQuote(flatforward.rate/100))
-    qlDayCounter = ql_day_count[flatforward.day_count]
-    qlCompounding = ql_compounding[flatforward.compounding]
-    qlFrequency = ql_frequency[flatforward.frequency]
+def qlFlatForward(flat: pym.FlatForwardCurve, ql_calendar = None):
     
-    return ql.FlatForward(qlDate, qlHandle, qlDayCounter, qlCompounding, qlFrequency)
+    
+    if not ql_calendar:
+        try:
+            qldate = ql.Date(flat.date, '%Y-%m-%d')
+            rate_handle = ql.QuoteHandle(ql.SimpleQuote(flat.rate/100))
+        except:
+            return None
+
+        if flat.compounding and flat.frequency and flat.day_count:
+            day_count = qlc.ql_day_count[flat.day_count]
+            compounding = qlc.ql_compounding[flat.compounding]
+            frequency = qlc.ql_frequency[flat.frequency]
+            return ql.FlatForward(qldate, rate_handle, day_count, compounding, frequency)
+
+        elif flat.compounding and flat.day_count:
+            day_count = qlc.ql_day_count[flat.day_count]
+            compounding = qlc.ql_compounding[flat.compounding]
+            return ql.FlatForward(qldate, rate_handle, day_count, compounding)
+
+        elif flat.day_count:
+            day_count = qlc.ql_day_count[flat.day_count]
+            return ql.FlatForward(qldate, rate_handle, day_count)
+        
+        else:
+            return None
+
+
+    else:
+        try:
+            rate_handle = ql.QuoteHandle(ql.SimpleQuote(flat.rate/100))
+        except:
+            return None
+
+        if flat.compounding and flat.frequency and flat.day_count:
+            day_count = qlc.ql_day_count[flat.day_count]
+            compounding = qlc.ql_compounding[flat.compounding]
+            frequency = qlc.ql_frequency[flat.frequency]
+            return ql.FlatForward(flat.start_basis, 
+                                ql_calendar, 
+                                rate_handle, 
+                                day_count, 
+                                compounding, 
+                                frequency)
+
+        elif flat.compounding and flat.day_count:
+            day_count = qlc.ql_day_count[flat.day_count]
+            compounding = qlc.ql_compounding[flat.compounding]
+            return ql.FlatForward(flat.start_basis, 
+                                ql_calendar, 
+                                rate_handle, 
+                                day_count, 
+                                compounding)
+        elif flat.day_count:
+            day_count = qlc.ql_day_count[flat.day_count]
+            return ql.FlatForward(flat.start_basis, 
+                                ql_calendar, 
+                                rate_handle, 
+                                day_count)
+        else:
+            return None
 
 
 def qlPiecewise(pwc: PiecewiseCurve, cal = None):
